@@ -7,7 +7,7 @@ sub handler {
 	my $r = shift;
 	$r->content_type("text/plain");
 	print "hhhh\n$INC[0]";
-	return 200;
+	return Apache2::Const::OK();
 }
 
 1;
